@@ -13,7 +13,6 @@ from aloft.process import execute
 from aloft.vpc import delete_vpc, get_or_create_vpc
 from subprocess import CalledProcessError
 
-
 def get_and_print_current_cluster(output_type):
     current_cluster_id = get_current_cluster_id()
     cluster = get_cluster_by_cluster_id(current_cluster_id)
@@ -215,7 +214,7 @@ def create_cluster_and_attach_network(cluster_id, vpc, options):
     host.wait_for_domain_to_resolve(cluster_id)
     aws.get_or_create_s3_bucket(state_store_name)
     create_cluster(cluster_id, vpc, options)
-    propagate_cluster_route_tables(cluster_id, vpn_name)
+    # propagate_cluster_route_tables(cluster_id, vpn_name)
     add_cluster_node_policies(cluster_id)
     wait_for_cluster_to_be_ready(cluster_id)
     initialize_helm()
