@@ -4,8 +4,7 @@ from aloft import cluster_config
 
 
 def get_or_create_vpc(vpc_id):
-    vpc_name = get_vpc_name_by_vpc_id(vpc_id)
-    vpc = get_vpc(vpc_name)
+    vpc = get_vpc(vpc_id)
 
     if not vpc:
         vpc = create_vpc(vpc_id)
@@ -14,6 +13,16 @@ def get_or_create_vpc(vpc_id):
 
 
 def get_vpc(vpc_name):
+    vpc_config = get_vpc_config(vpc_name)
+    aws_vpc_name = vpc_config[vpc_name.split('.',1)[0]]
+    vpc = None
+    if aws_vpc_name is None:
+        vpc = aws.get_vpc_by_name(vpc_name)
+    else:
+        vpc = aws.get_vpc_by_name(aws_vpc_name)
+    return vpc
+
+def xget_vpc(vpc_name):
     return aws.get_vpc_by_name(vpc_name)
 
 
